parallel

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 18, 2020 License: MIT Imports: 1 Imported by: 4

README

go-parallel

PkgGoDev Go Report Card Build Status

Simple parallel processing utilities for Go.

See the API documentation for more details.

This software is made available under an MIT license.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunWorkers

func RunWorkers(n int, worker func(workerNum, workerCount int))

RunWorkers executes the specified worker function using n goroutines, passing each a workerNum from 0-n and a workerCount of n. This function returns after all workers have run to completion.

Types

This section is empty.

Jump to