Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RunWorkers ¶
RunWorkers executes the specified worker function using n goroutines, passing each a workerNum from 0-n and a workerCount of n. This function returns after all workers have run to completion.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.